@@ -1,10 +1,11 @@
-      SUBROUTINE WDGEES( WRAP, SELECT, N, A, LDA, SDIM, WR, WI,
-     $                  VS, LDVS, WORK, LWORK, BWORK, INFO )
+      SUBROUTINE WDGEES( IWRAP, SELECT, N, A, LDA, SDIM, WR, WI,
+     $                  VS, LDVS, WORK, LWORK, IBWORK, INFO )
 *     .. Scalar Arguments ..
-      INTEGER            WRAP
+      INTEGER            IWRAP
       INTEGER            INFO, LDA, LDVS, LWORK, N, SDIM
 *     .. Array Arguments ..
-      LOGICAL            BWORK( * )
+      INTEGER            IBWORK( * )
+      LOGICAL            BWORK( N )
       DOUBLE PRECISION   A( LDA, * ), VS( LDVS, * ), WI( * ), WORK( * ),
      $                   WR( * )
 *     .. Function Arguments ..
@@ -14,13 +15,22 @@
       EXTERNAL           DGEES
 *
       CHARACTER          JOBVS, SORT
-      IF (WRAP .EQ. 0) THEN
+*
+      IF (IWRAP .EQ. 0) THEN
           JOBVS = 'V'
           SORT = 'N'
-      ELSE IF (WRAP .EQ. 1) THEN
+      ELSE IF (IWRAP .EQ. 1) THEN
           JOBVS = 'N'
           SORT = 'N'
       END IF
+*
+      DO 10 I = 1, N
+         IF (IBWORK(I) .EQ. 1) THEN
+            BWORK(I) = .TRUE.
+         ELSE
+            BWORK(I) = .FALSE.
+         END IF
+   10 CONTINUE
 *
       CALL DGEES( JOBVS, SORT, SELECT, N, A, LDA, SDIM, WR, WI,
      $            VS, LDVS, WORK, LWORK, BWORK, INFO )
