@@ -1,7 +1,7 @@
-      SUBROUTINE WZGEEV( WRAP, N, A, LDA, W, VL, LDVL, VR, LDVR,
+      SUBROUTINE WZGEEV( IWRAP, N, A, LDA, W, VL, LDVL, VR, LDVR,
      $                  WORK, LWORK, RWORK, INFO ) 
 *     .. Scalar Arguments ..
-      INTEGER            WRAP
+      INTEGER            IWRAP
       INTEGER            INFO, LDA, LDVL, LDVR, LWORK, N
 *     .. Array Arguments ..
       DOUBLE PRECISION   RWORK( * )
@@ -11,16 +11,16 @@
       EXTERNAL           ZGEEV
 *
       CHARACTER          JOBVL, JOBVR
-      IF (WRAP .EQ. 0) THEN
+      IF (IWRAP .EQ. 0) THEN
           JOBVL = 'V'
           JOBVR = 'V'
-      ELSE IF (WRAP .EQ. 1) THEN
+      ELSE IF (IWRAP .EQ. 1) THEN
           JOBVL = 'N'
           JOBVR = 'V'
-      ELSE IF (WRAP .EQ. 2) THEN
+      ELSE IF (IWRAP .EQ. 2) THEN
           JOBVL = 'V'
           JOBVR = 'N'
-      ELSE IF (WRAP .EQ. 3) THEN
+      ELSE IF (IWRAP .EQ. 3) THEN
           JOBVL = 'N'
           JOBVR = 'N'
       END IF
